function [modelJointHighFat]=changeDietHighFatRecon2(modelJoint)

% A function for automatically assigning a HighFat diet defined in this
% script to the joint models.

% INPUT : Joint model structure
% OUPUT : Joint model structure with dietary constraints implemented

modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('Ex_',modelJoint.rxns)),0,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pi[u]'},-10,'l');

% HighFat diet, based on "What we eat in America"
% sugars
modelJoint=changeRxnBounds(modelJoint,{'Ex_fru[u]';'Ex_glc-D[u]';'Ex_gal[u]';'Ex_man[u]'},-0.03125,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lcts[u]';'Ex_malt[u]';'Ex_sucr[u]';'Ex_melib[u]'},-0.015625,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_strch1[u]',-0.0227273,'l');
% fibers
modelJoint=changeRxnBounds(modelJoint,'Ex_inulin[u]',-0.0013889,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_levan1000[u]',-0.0000417,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_starch1200[u]'},-0.0000347,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_arabinogal[u]',-0.0000647,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_pect[u]',-0.0000986,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_pullulan1200[u]',-0.0000347,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_amylose300[u]',-0.0001389,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_lmn30[u]',-0.0013889,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_raffin[u]',-0.013889,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_stys[u]',-0.0104167,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_oligofru4[u]',-0.0104167,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_dextran40[u]',-0.0005208,'l');
% fat
modelJoint=changeRxnBounds(modelJoint,{'Ex_arachd[u]'},-0.0082870,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_chsterol[u]'},-0.0123423,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_glyc[u]'},-4.4811406,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_hdca[u]'},-0.9869635,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_hdcea[u]'},-0.0909273,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlc[u]'},-0.8941927,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlnca[u]'},-0.0437377,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlncg[u]'},-0.0437377,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ocdca[u]'},-0.4215188,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ocdcea[u]'},-1.6968176,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_octa[u]'},-0.0322274,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ttdca[u]'},-0.1709956,'l');
% protein
modelJoint=changeRxnBounds(modelJoint,{'Ex_ala-L[u]';'Ex_ser-L[u]';'Ex_cys-L[u]'},-0.3,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_arg-L[u]';'Ex_ile-L[u]';'Ex_leu-L[u]';'Ex_lys-L[u]';'Ex_his-L[u]'},-0.15,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_asn-L[u]';'Ex_asp-L[u]';'Ex_thr-L[u]'},-0.225,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_glu-L[u]';'Ex_met-L[u]';'Ex_gln-L[u]';'Ex_pro-L[u]';'Ex_val-L[u]'},-0.18,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_phe-L[u]';'Ex_tyr-L[u]'},-0.099,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_gly[u]'},-0.45,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_trp-L[u]'},-0.081,'l');
% minerals and vitamins
% bacterial requirements pooled
modelJoint=changeRxnBounds(modelJoint,{'Ex_thm[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ribflv[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_nac[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_btn[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pnto-R[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydxn[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydx[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydam[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_thf[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_adocbl[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_retinol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_vitd3[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_phyQ[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_avite1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pheme[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cbl1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_chol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_h2s[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_so4[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_spmd[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_na1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ca2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cobalt2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cl[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_k[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe3[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe3dcit[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mg2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mn2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mobd[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cu2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_zn2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_sel[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pime[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mqn8[u]'},-1,'l');
% for L. lactis
modelJoint=changeRxnBounds(modelJoint,{'Ex_orot[u]'},-1,'l');
% for S. aureus
modelJoint=changeRxnBounds(modelJoint,{'Ex_csn[u]'},-1,'l');

if find(ismember(modelJoint.rxns,'HPBiomassHP_published'));
% required for growth of H. pylori
modelJoint=changeRxnBounds(modelJoint,{'Ex_o2[u]'},-7,'l');
% prevent oxygen uptake of other microbes
modelJoint=changeRxnBounds(modelJoint,'BTIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'FPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'ECIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'LPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'LLIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'STIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'KPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'SEIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'ESIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'EEIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'SAIEx_o2[u]tr',0,'l');
end

modelJointHighFat=modelJoint;



