function [modelJointHighProtein]=changeDietHighProteinRecon2(modelJoint)

% A function for automatically assigning a HighProtein diet defined in this
% script to the joint models.

% INPUT : Joint model structure
% OUPUT : Joint model structure with dietary constraints implemented

modelJoint = changeRxnBounds(modelJoint,modelJoint.rxns(strmatch('Ex_',modelJoint.rxns)),0,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pi[u]'},-10,'l');

% HighProtein diet, based on "What we eat in America"
% sugars
modelJoint=changeRxnBounds(modelJoint,{'Ex_fru[u]';'Ex_glc-D[u]';'Ex_gal[u]';'Ex_man[u]'},-0.0156250,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lcts[u]';'Ex_malt[u]';'Ex_sucr[u]';'Ex_melib[u]'},-0.0078125,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_strch1[u]',-0.0113636,'l');
% fibers
modelJoint=changeRxnBounds(modelJoint,'Ex_inulin[u]',-0.0006944,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_levan1000[u]',-0.0000208,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_starch1200[u]'},-0.0000174,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_arabinogal[u]',-0.0000324,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_pect[u]',-0.0000493,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_pullulan1200[u]',-0.0000174,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_amylose300[u]',-0.0000694,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_lmn30[u]',-0.0006944,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_raffin[u]',-0.0069444,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_stys[u]',-0.0052083,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_oligofru4[u]',-0.0052083,'l');
modelJoint=changeRxnBounds(modelJoint,'Ex_dextran40[u]',-0.0002604,'l');
% fat
modelJoint=changeRxnBounds(modelJoint,{'Ex_arachd[u]'},-0.0022099,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_chsterol[u]'},-0.0032913,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_glyc[u]'},-1.1949708,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_hdca[u]'},-0.2631903,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_hdcea[u]'},-0.0242473,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlc[u]'},-0.2384514,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlnca[u]'},-0.0116634,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_lnlncg[u]'},-0.0116634,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ocdca[u]'},-0.11240505,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ocdcea[u]'},-0.4524847,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_octa[u]'},-0.0085940,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ttdca[u]'},-0.0455988,'l');
% protein
modelJoint=changeRxnBounds(modelJoint,{'Ex_ala-L[u]';'Ex_ser-L[u]';'Ex_cys-L[u]'},-1.5,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_arg-L[u]';'Ex_ile-L[u]';'Ex_leu-L[u]';'Ex_lys-L[u]';'Ex_his-L[u]'},-0.75,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_asn-L[u]';'Ex_asp-L[u]';'Ex_thr-L[u]'},-1.125,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_glu-L[u]';'Ex_met-L[u]';'Ex_gln-L[u]';'Ex_pro-L[u]';'Ex_val-L[u]'},-0.90,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_phe-L[u]';'Ex_tyr-L[u]'},-0.495,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_gly[u]'},-2.25,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_trp-L[u]'},-0.405,'l');
% minerals and vitamins
% bacterial requirements pooled
modelJoint=changeRxnBounds(modelJoint,{'Ex_thm[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ribflv[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_nac[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_btn[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pnto-R[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydxn[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydx[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pydam[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_thf[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_adocbl[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_retinol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_vitd3[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_phyQ[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_avite1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pheme[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cbl1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_chol[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_h2s[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_so4[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_spmd[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_na1[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_ca2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cobalt2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cl[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_k[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe3[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_fe3dcit[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mg2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mn2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mobd[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_cu2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_zn2[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_sel[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_pime[u]'},-1,'l');
modelJoint=changeRxnBounds(modelJoint,{'Ex_mqn8[u]'},-1,'l');
% for L. lactis
modelJoint=changeRxnBounds(modelJoint,{'Ex_orot[u]'},-1,'l');
% for S. aureus
modelJoint=changeRxnBounds(modelJoint,{'Ex_csn[u]'},-1,'l');

if find(ismember(modelJoint.rxns,'HPBiomassHP_published'));
% required for growth of H. pylori
modelJoint=changeRxnBounds(modelJoint,{'Ex_o2[u]'},-7,'l');
% prevent oxygen uptake of other microbes
modelJoint=changeRxnBounds(modelJoint,'BTIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'FPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'ECIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'LPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'LLIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'STIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'KPIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'SEIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'ESIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'EEIEx_o2[u]tr',0,'l');
modelJoint=changeRxnBounds(modelJoint,'SAIEx_o2[u]tr',0,'l');
end

modelJointHighProtein=modelJoint;


