function [JointModelsObjectives, FVAJointModels]=performObjectivesRecon2(JointModelsObjectives,FVAJointModels,modelJoint,hostID,modelID,diet,FVAflag)

% This function calls a number of objectives to be carried out for all
% joint models.
% Almut Heinken 05/12
% 03/2014: added saving fluxes computed by FBA

% INPUT: modelJoint: Joint model structure
%        hostID: HS
%        modelID: identifier germfree/ joint bacterial model
%        diet: identifier (Western/ HighFat/ HighCarb/ HighProtein) to identify the file
%        FVAflag: should FVA with host biomass as objective be performed?
%        slow)
% OUTPUT: Files with calculated objective flux values

if FVAflag==false
    FVAJointModels=[];
end

% first 24 objectives: manually defined

%for i=1:24
for i=1
    for j=1:2
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
    end
end


%for i=1:24
for i=1
    for j=1:2
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}=zeros;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}=zeros;
    end
end


%%% put objective names in the first row %%%
% simulation condition
JointModelsObjectives.(strcat(hostID,diet)).(modelID){1,1}=modelID;
JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){1,1}=modelID;
JointModelsObjectives.(strcat(hostID,diet)).(modelID){1,2}=diet;
JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){1,2}=diet;

% biomass
JointModelsObjectives.(strcat(hostID,diet)).(modelID){2,1}=strcat(hostID,'biomass_reaction');
JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){2,1}=strcat(hostID,'biomass_reaction');

% count number of objectives until now
s =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);

% all body fluid secretion exchanges as objectives
BodyFluidExchanges=strmatch(strcat(hostID,'EX_'),modelJoint.rxns);


for i=s+1:s+size(BodyFluidExchanges,1)
    for j=1:2
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
    end
end

for k=1:size(BodyFluidExchanges,1)
    JointModelsObjectives.(strcat(hostID,diet)).(modelID){s+k,1}=modelJoint.rxns(BodyFluidExchanges(k),1);
    JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){s+k,1}=modelJoint.rxns(BodyFluidExchanges(k),1);
end


% count number of objectives until now again
t =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);

% all faecal secretion exchanges as objectives
FaecalExchanges=strmatch('Ex_',modelJoint.rxns);

for i=t+1:t+size(FaecalExchanges,1)
    for j=1:2
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
    end
end

for l=1:size(FaecalExchanges,1)
    JointModelsObjectives.(strcat(hostID,diet)).(modelID){t+l,1}=modelJoint.rxns(FaecalExchanges(l),1);
    JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){t+l,1}=modelJoint.rxns(FaecalExchanges(l),1);
end

% count number of objectives until now again
u =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);


% all internal exchanges as objectives
InternalExchanges=strmatch(strcat(hostID,'IEX_'),modelJoint.rxns);

for i=u+1:u+size(InternalExchanges,1)
    for j=1:2
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
    end
end

for m=1:size(InternalExchanges,1)
    JointModelsObjectives.(strcat(hostID,diet)).(modelID){u+m,1}=modelJoint.rxns(InternalExchanges(m),1);
    JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){u+m,1}=modelJoint.rxns(InternalExchanges(m),1);
end

% for bacterial internal exchanges
if ~strcmp(modelID,'GF')
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'BTBiomass_BT_v2'));
        BTInternalExchanges=strmatch(strcat('BTIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(BTInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(BTInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(BTInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(BTInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'FPBiomass_FP'));
        FPInternalExchanges=strmatch(strcat('FPIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(FPInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(FPInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(FPInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(FPInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'ECEC_BIOMASS_IAF1260_WT_59P81M'));
        ECInternalExchanges=strmatch(strcat('ECIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(ECInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(ECInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(ECInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(ECInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'LPbiomass_LPL60'));
        LPInternalExchanges=strmatch(strcat('LPIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(LPInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(LPInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(LPInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(LPInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'LLbiomass_LLA'));
        LLInternalExchanges=strmatch(strcat('LLIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(LLInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(LLInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(LLInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(LLInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'STbiomass_STR'));
        STInternalExchanges=strmatch(strcat('STIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(STInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(STInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(STInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(STInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'HPBiomassHP_published'));
        HPInternalExchanges=strmatch(strcat('HPIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(HPInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(HPInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(HPInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(HPInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'KPBiomass'));
        KPInternalExchanges=strmatch(strcat('KPIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(KPInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(KPInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(KPInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(KPInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'SEbiomass_iRR1083_metals'));
        SEInternalExchanges=strmatch(strcat('SEIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(SEInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(SEInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(SEInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(SEInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'ESEC_BIOMASS_IAF1260_WT_59P81M'));
        ESInternalExchanges=strmatch(strcat('ESIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(ESInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(ESInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(ESInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(ESInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'EEEC_BIOMASS_IAF1260_WT_59P81M'));
        EEInternalExchanges=strmatch(strcat('EEIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(EEInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(EEInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(EEInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(EEInternalExchanges(n),1);
        end
    end
    
    % count number of objectives until now again
    v =size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1);
    
    % all bacterial internal exchanges as objectives
    if find(ismember(modelJoint.rxns,'SAbiomass_SA_8a'));
        SAInternalExchanges=strmatch(strcat('SAIEX_'),modelJoint.rxns);
        
        for i=v+1:v+size(SAInternalExchanges,1)
            for j=1:2
                JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,j}='none';
                JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,j}='none';
            end
        end
        
        for n=1:size(SAInternalExchanges,1)
            JointModelsObjectives.(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(SAInternalExchanges(n),1);
            JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){v+n,1}=modelJoint.rxns(SAInternalExchanges(n),1);
        end
    end
    
end

% solver
solverOK=changeCobraSolver('tomlab_cplex');
%solverOK=changeCobraSolver('glpk');

% biomass objectives including FVAs
modelJoint=changeObjective(modelJoint,strcat(hostID,'biomass_reaction'));
modelJoint.osense=-1;

if FVAflag==true
    disp('Performing FVA...');
    [minFlux maxFlux,optsol,ret]=fastFVA(modelJoint,99.999,'max','cplex');
    %[minFlux maxFlux,optsol,ret]=fastFVA(modelJoint,99.999,'max','glpk');
    FVAJointModels.(strcat(hostID,diet)).(modelID).('BiomassHost')=modelJoint.rxns;
    for i=1:length(modelJoint.rxns)
        FVAJointModels.(strcat(hostID,diet)).(modelID).('BiomassHost'){i,2}=minFlux(i,1);
    end
    for i=1:length(modelJoint.rxns)
        FVAJointModels.(strcat(hostID,diet)).(modelID).('BiomassHost'){i,3}=maxFlux(i,1);
    end
else disp('FVA not performed.');
end

% 
% then the exchange objectives
% make sure internal exchange objectives are first minimized then maximized
for i=2:size(JointModelsObjectives.(strcat(hostID,diet)).(modelID),1)
    modelJoint.osense=-1;
    modelJoint=changeObjective(modelJoint,JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1});
    if strmatch('HSIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('BTIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('FPIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('ECIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('LPIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('LLIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('STIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('HPIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('KPIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('SEIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('ESIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    if strmatch('EEIEX',JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1})
        solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
        % to remove the tiny values that are really zero
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,3}=solution.obj;
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,3}=solution.full;
        modelJoint.osense=1;
        JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
        if abs(solution.obj) < 0.0000000001
            solution.obj=0;
        end
        JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    end
    hostID,modelID
    diet
    JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,1}

    solution=solveCobraLPCPLEX(modelJoint,2,0,0,[],0);
    % to remove the tiny values that are really zero
    if abs(solution.obj) < 0.0000000001
        solution.obj=0;
    end
    JointModelsObjectives.(strcat(hostID,diet)).(modelID){i,2}=solution.obj;
    JointModelsObjectives.('Fluxes').(strcat(hostID,diet)).(modelID){i,2}=solution.full;
    %     end
    
end

